(ns com.aurellem.run.basic_choreo
  (:use (com.aurellem.gb saves gb-driver util constants
                         items vbm characters money
                         rlm-assembly))
  (:use (com.aurellem.run util music title save-corruption
                          bootstrap-0 bootstrap-1 image
                          ram-display))
  (:require clojure.string)
  (:import [com.aurellem.gb.gb_driver SaveState])
  (:import java.io.File))



;; take over game
;; [X] silence noise
;; [ ] run picture program to display pinkie pie mark
;; [ ] play pony song 


(defn-memo silence-noise
  ([] (silence-noise (relocate-main-bootstrap)))
  ([script]
     (->> script
          (write-RAM 0xFF1A [0 0 0]))))

(def music-program-start 0xC000)
(def image-program-start 0xCE00)

(defn-memo write-pony-music-data
  ([] (write-pony-music-data (silence-noise)))
  ([script]
     (let [bytes (midi-bytes
                  pony-csv
                  0xC400
                  0xC800
                  0xCC00
                  0xC000)]
       (->> script
            (write-RAM (:address (:voice-1 bytes))
                       (:data    (:voice-1 bytes)))
            (write-RAM (:address (:voice-2 bytes))
                       (:data    (:voice-2 bytes)))
            (write-RAM (:address (:noise bytes))
                       (:data    (:noise bytes)))
            (write-RAM (:address (:kernel bytes))
                       (:data    (:kernel bytes)))))))

(defn-memo write-image-display-program
  ([] (write-image-display-program (write-pony-music-data)))
  ([script]
     (let [return-to-bootstrap
           (flatten
            [0xC3
             (disect-bytes-2 relocated-bootstrap-start)])]
       (->> script
            (write-RAM
             image-program-start
             (concat
              (display-image-kernel
               image-program-start
               pinkie-pie-mark)
              return-to-bootstrap))))))
     
(defn-memo activate-media
  ([] (activate-media (write-image-display-program)))
  ([script]
     (->> script
          (transfer-control image-program-start)
          (do-nothing 100)
          (transfer-control music-program-start))))


